# Python bindings for `nucypher-core`

[![pypi package][pypi-image]][pypi-link] [![Docs][rtd-image]][rtd-link] ![License][pypi-license-image]

This repo contains the Python bindings for the [main Rust project][nucypher-core].


## Build

You will need to have `setuptools-rust` installed. Then, for development you can just do `pip install -e .` as usual.


[pypi-image]: https://img.shields.io/pypi/v/nucypher-core
[pypi-link]: https://pypi.org/project/nucypher-core/
[pypi-license-image]: https://img.shields.io/pypi/l/nucypher-core
[rtd-image]: https://readthedocs.org/projects/nucypher-core/badge/?version=latest
[rtd-link]: https://nucypher-core.readthedocs.io/en/latest/
[nucypher-core]: https://github.com/nucypher/nucypher-core/tree/master/nucypher-core
